@@ -130,7 +130,7 @@ def by_lexicon(a: Annotation):
 
 
 def by_label(a: Annotation):
-    return a.label
+    return a.label or a.labelName
 
 
 def one_match(a: Annotation, matches: RangeMap):
